/**
 * 存储管理工具
 */

const STORAGE_PREFIX = 'aimz_';

// 获取完整的存储键名
const getFullKey = (key) => {
    return `${STORAGE_PREFIX}${key}`;
};

// 设置存储
const set = (key, data) => {
    try {
        const fullKey = getFullKey(key);
        wx.setStorageSync(fullKey, data);
        return true;
    } catch (error) {
        console.error('Storage set error:', error);
        return false;
    }
};

// 获取存储
const get = (key, defaultValue = null) => {
    try {
        const fullKey = getFullKey(key);
        const value = wx.getStorageSync(fullKey);
        return value || defaultValue;
    } catch (error) {
        console.error('Storage get error:', error);
        return defaultValue;
    }
};

// 移除存储
const remove = (key) => {
    try {
        const fullKey = getFullKey(key);
        wx.removeStorageSync(fullKey);
        return true;
    } catch (error) {
        console.error('Storage remove error:', error);
        return false;
    }
};

// 清除所有存储
const clear = () => {
    try {
        wx.clearStorageSync();
        return true;
    } catch (error) {
        console.error('Storage clear error:', error);
        return false;
    }
};

// 获取存储信息
const info = () => {
    try {
        return wx.getStorageInfoSync();
    } catch (error) {
        console.error('Storage info error:', error);
        return null;
    }
};

module.exports = {
    set,
    get,
    remove,
    clear,
    info
};